==> libreoffice_4.2.3~rc3.orig-src.tar.xz: libodfgen-0.0.4/src/InternalHandler.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libodfgen
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2007 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#include "InternalHandler.hxx"

#include <string.h>

InternalHandler::InternalHandler(std::vector<DocumentElement *> *elements):
	mpElements(elements)
{
}

void InternalHandler::startElement(const char *psName, const WPXPropertyList &xPropList)
{
	TagOpenElement *element = new TagOpenElement(psName);
	WPXPropertyList::Iter i(xPropList);
	for (i.rewind(); i.next(); )
	{
		// filter out libwpd elements
		if (strncmp(i.key(), "libwpd", 6) != 0)
			element->addAttribute(i.key(), i()->getStr());
	}
	mpElements->push_back(element);
}

void InternalHandler::endElement(const char *psName)
{
	mpElements->push_back(new TagCloseElement(psName));
}

void InternalHandler::characters(const WPXString &sCharacters)
{
	mpElements->push_back(new CharDataElement(sCharacters.cstr()));
}

/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */

==> libreoffice_5.1.2.orig-src.tar.xz: libodfgen-0.1.6/src/InternalHandler.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libodfgen
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2007 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#include "InternalHandler.hxx"

#include <string.h>

void InternalHandler::startElement(const char *psName, const librevenge::RVNGPropertyList &xPropList)
{
	TagOpenElement *element = new TagOpenElement(psName);
	librevenge::RVNGPropertyList::Iter i(xPropList);
	for (i.rewind(); i.next();)
	{
		// filter out librevenge elements
		if (strncmp(i.key(), "librevenge:", 11))
			element->addAttribute(i.key(), i()->getStr());
	}
	mpElements->push_back(element);
}

void InternalHandler::endElement(const char *psName)
{
	mpElements->push_back(new TagCloseElement(psName));
}

void InternalHandler::characters(const librevenge::RVNGString &sCharacters)
{
	mpElements->push_back(new CharDataElement(sCharacters.cstr()));
}

/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
